# Changelog
All notable changes to this project will be documented in this file.

The format is based on [Keep a Changelog](https://keepachangelog.com/en/1.0.0/),
and this project adheres to [Semantic Versioning](https://semver.org/spec/v2.0.0.html).

## [Unreleased]


## [0.1.1] - 2021-05-03
### Changed
- Fix a timezone issue for daily schedules.
- Amend and reformat readme.
- Add docstrings and typing.


## [0.1.0] - 2021-05-02
### Added
- Initial release

[Unreleased]: https://edugit.org/nik/gibihm
[0.1.1]: https://edugit.org/nik/gibihm/-/tree/0.1.1
[0.1.0]: https://edugit.org/nik/gibihm/-/tree/0.1.0
